@@ -11,6 +11,7 @@ from Crypto.Protocol.KDF import PBKDF2
 from cryptography.fernet import Fernet
 from random import randbytes, shuffle
 from platform import system as get_platform
+from file_encryption import AES_encrypt_file, AES_decrypt_file, BLO_encrypt_file, BLO_decrypt_file 
 
 class NoKeyError(Exception):
     """
@@ -46,6 +47,8 @@ def hash_(StringToHash=str, hash_code = str, return_type = "hex") -> str:
     SHA 512 / CODE = SHA512
     
     MD5 / CODE = MD5
+
+    return_type: whether or not to return hex. specify 'bytes' if needed.
     """
     if hash_code == "SHA224":
         hash_obj = hash.sha224(StringToHash.encode())
@@ -108,7 +111,7 @@ def token_generation(size=int, return_type = str):
         return token
 
 
-def gen_random_password(length=int):
+def gen_random_password(length:int):
     characters = list(string.ascii_letters + string.digits + "!@#$%^&*()")
     shuffle(characters)
     password = []
@@ -125,7 +128,7 @@ def sec_delete(file_path, random_fill = True, null_fill = True, passes = 35) ->
 
     It is best practice to combine this with another secure file deletion protocol.
     """
-    if "/home/" not in file_path or "/." in file_path:
+    if "/home/" not in file_path or "/." in file_path and get_platform=="Linux":
         return 1
     else:
         with open (file_path, "wb") as file:
@@ -139,6 +142,7 @@ def sec_delete(file_path, random_fill = True, null_fill = True, passes = 35) ->
             for _ in passes:
                 with open (file_path, "wb") as file:
                     file.write("\x00" * length)
+        os.system("rm {}".format(file_path))
         return 0
 
 
@@ -177,13 +181,13 @@ class Ciphers:
         if salt is None:
             salt_ = os.urandom(32)
             key = PBKDF2(self.password, salt_, dkLen=32)
-            return key, salt
+            return key, salt_
         else:
             key = PBKDF2(self.password, salt, dkLen=32)
             return key
 
 
-    def generate_FerNet_key():
+    def generate_FerNet_key(self):
         key = Fernet.generate_key()
         return key
 
@@ -233,7 +237,7 @@ class Ciphers:
         elif file_marker != self.marker and decrypting is True:
             return 7
         if decrypting is True:
-            if str(type_of_file) != type_:
+            if type_of_file.decode() != type_:
                 return 8
             else:
                 return 0
@@ -270,7 +274,7 @@ class Ciphers:
         # AES methods
 
 
-    def AES_encrypt_file(self, path=str) -> int:
+    def AES_encrypt_file(self, path:str) -> int:
         """
         A method for encrypting a file/folder object with AES.
 
@@ -286,63 +290,15 @@ class Ciphers:
             5: File is part of root filesystem (Linux only)
             6: File encryption marker detected during encryption.
         """
-        # encryption for single file
-        if os.path.isfile(path) is True:
-            # checking if the file path is ok
-            return_code = self.check_path_validity(path, decrypting=False, type_="AES")
-            if return_code != 0:
-                return return_code
-                # generating a key and key signature
-            salt = os.urandom(32)
-            iv = os.urandom(16)
-            key_and_salt = self.generate_symmetric_key(salt=None)
-            key = key_and_salt[0]; salt = key_and_salt[1]
-            key_hash = hash.sha256(key); key_signature = key_hash.digest()
-            # getting the data and setting a cipher (using CFB to avoid padding.)
-            with open (path, "rb") as file:
-                data = file.read()
-            cipher = AES.new(key, AES.MODE_CFB, iv=iv)
-            # ciphering and writing
-            ciphered_data = cipher.encrypt(data)
-            with open(path, "wb") as file:
-                file.write(b"AES")
-                file.write(self.marker)
-                file.write(iv)
-                file.write(salt)
-                file.write(key_signature)
-                file.write(ciphered_data)
-            return 0
-        # encryption for directory.
-        elif os.path.isdir(path) is True:
-            # looping through files in dir
-            for root, dirs, files in os.walk(path):
-                for file in files:
-                    # checking if each file is suitable for encryption
-                    file_name = os.path.join(root, file)
-                    return_code = self.check_path_validity(file_name, decrypting=False, type_='AES')
-                    if return_code != 0:
-                        continue
-                    salt = os.urandom(32)
-                    iv = os.urandom(16)
-                    key_and_salt = self.generate_symmetric_key(salt=None)
-                    key = key_and_salt[0]; salt = key_and_salt[1]
-                    key_hash = hash.sha256(key); key_signature = key_hash.digest()
-                    # getting data and setting cipher
-                    with open (file_name, "rb") as file:
-                        data = file.read()
-                    cipher = AES.new(key, AES.MODE_CFB, iv=iv)
-                    # ciphering and writing.
-                    ciphered_data = cipher.encrypt(data)
-                    with open(file_name, "wb") as file:
-                        file.write(self.marker)
-                        file.write(iv)
-                        file.write(salt)
-                        file.write(key_signature)
-                        file.write(ciphered_data)
-            return 0
+        # checking if the file path is ok
+        return_code = self.check_path_validity(path, decrypting=False, type_="AES")
+        if return_code != 0:
+            return return_code
+        AES_encrypt_file(self.password, path)
+        return 0
 
 
-    def AES_decrypt_file(self, path=str) -> int:
+    def AES_decrypt_file(self, path:str) -> int:
         """
         A method for decrypting an encrypted file that was encrypted with AES.
 
@@ -359,64 +315,16 @@ class Ciphers:
             7: File was not encrypted.
             8: File was encrypted using a different alogorithm.
         """
-        # decryption for single file
-        if os.path.isfile(path) is True:
-            # checking if file is suitable
-            return_code = self.check_path_validity(path, decrypting=True, type_="AES")
-            if return_code != 0:
-                return return_code
-                # gathering needed data
-            with open (path, "rb") as file:
-                file.read(3)
-                file.read(14)
-                iv = file.read(16)
-                salt = file.read(32)
-                file_signature = file.read(32)
-                ciphered_data = file.read()
-                # building key and key hash, then comparing key hash to file signature
-            key = self.generate_symmetric_key(salt=salt)
-            key_hash = hash.sha256(key); key_signature = key_hash.digest()
-            if file_signature != key_signature:
-                raise BadKeyError("Keys are not the same.")
-            # setting cipher and decrypting the data
-            cipher = AES.new(key, AES.MODE_CFB, iv=iv)
-            original_data = cipher.decrypt(ciphered_data)
-            # writing
-            with open(path, "wb") as file:
-                file.write(original_data)
-            return 0
-        # directory decryption
-        elif os.path.isdir(path) is True:
-            # looping through files
-            for root, dirs, files in os.walk(path):
-                for file in files:
-                    # checking if file is suitable
-                    file_name = os.path.join(root, file)
-                    return_code = self.check_path_validity(file_name, decrypting=True)
-                    if return_code != 0:
-                        continue
-                    # gathering needed data
-                    with open (file_name, "rb") as file:
-                        file.read(14)
-                        iv = file.read(16)
-                        salt = file.read(32)
-                        file_signature = file.read(32)
-                        ciphered_data = file.read()
-                    # building key/key hash and comparing to file signature
-                    key = self.generate_symmetric_key(salt=salt)
-                    key_hash = hash.sha256(key); key_signature = key_hash.digest()
-                    if key_signature != file_signature:
-                        continue
-                    # building the cipher and decrypting the data
-                    cipher = AES.new(key, AES.MODE_CFB, iv=iv)
-                    original_data = cipher.decrypt(ciphered_data)
-                    # decrypting
-                    with open (file_name, "wb") as file:
-                        file.write(original_data)
-            return 0
-        
+        # checking if file is suitable
+        return_code = self.check_path_validity(path, decrypting=True, type_="AES")
+        if return_code != 0:
+            return return_code
+        # passing path onto compiled Cython code
+        AES_decrypt_file(self.password, path)
+        return 0
 
-    def AES_encrypt_string(self, key=bytes or None, string_to_encrypt=bytes):
+
+    def AES_encrypt_string(self, key=None, string_to_encrypt=bytes):
         """
         Method for encrypting strings using the AES encryption alogrithm in CFB mode.
 
@@ -429,7 +337,7 @@ class Ciphers:
             salt = os.urandom(32)
             key = self.generate_symmetric_key(salt)
         iv = os.urandom(16)
-        cipher = Blowfish.new(key, Blowfish.MODE_CFB, iv=iv)
+        cipher = AES.new(key, AES.MODE_CFB, iv=iv)
         ciphered_string = cipher.encrypt(string_to_encrypt)
         return (ciphered_string, iv, key)
 
@@ -446,7 +354,7 @@ class Ciphers:
         """
         if key is None:
             raise NoKeyError("No key was provided for the cipher.")
-        cipher = Blowfish.new(key, Blowfish.MODE_CFB, iv=iv)
+        cipher = AES.new(key, AES.MODE_CFB, iv=iv)
         decrypted_string = cipher.decrypt(encrypted_string)
         return (decrypted_string)
 
@@ -454,7 +362,7 @@ class Ciphers:
     # Blowfish methods
 
 
-    def BLO_encrypt_file(self, path=str):
+    def BLO_encrypt_file(self, path:str):
         """
         A method for encrypting a file/folder object with Blowfish in CFB mode..
 
@@ -470,61 +378,13 @@ class Ciphers:
             5: File is part of root filesystem (Linux only)
             6: File encryption marker detected during encryption.
         """
-        # file encryption
-        if os.path.isfile(path) is True:
-            # checking if file is suitable
-            return_code = self.check_path_validity(path, decrypting=False, type_="BLO")
-            if return_code != 0:
-                return return_code
-            # generating a key, salt, and key signature
-            key_and_salt = self.generate_symmetric_key(salt=None)
-            key = key_and_salt[0]; salt = key_and_salt[1]
-            key_hash = hash.sha256(key); key_signature = key_hash.digest()
-            iv = os.urandom(8) # generating IV (blowfish only takes 8)
-            # getting data and setting the cipher
-            with open (path, "rb") as file:
-                data = file.read()
-            cipher = Blowfish.new(key, Blowfish.MODE_CFB, iv=iv)
-            # encrypting the data and writing.
-            ciphered_data = cipher.encrypt(data)
-            with open (path, "wb") as file:
-                file.write(b"BLO")
-                file.write(self.marker)
-                file.write(iv)
-                file.write(salt)
-                file.write(key_signature)
-                file.write(ciphered_data)
-            return 0
-        # directory encryption.
-        elif os.path.isdir(path) is True:
-            # looping through files in dir
-            for root, dirs, files in os.walk(path):
-                for file in files:
-                    # checking if files are suitable
-                    file_name = os.path.join(root, file)
-                    return_code = self.check_path_validity(path, decrypting=False, type_="BLO")
-                    if return_code != 0:
-                        continue
-                    # getting data from file
-                    with open(file_name, "rb") as file:
-                        data = file.read()
-                    # generating a key and building a key signature
-                    key_and_salt = self.generate_symmetric_key(salt=None)
-                    key = key_and_salt[0]
-                    salt = key_and_salt[1]
-                    key_hash = hash.sha256(key); key_signature = key_hash.digest()
-                    iv = os.urandom(8) # IV for cipher
-                    # setting cipher and encrypting data
-                    cipher = Blowfish.new(key, Blowfish.MODE_CFB, iv=iv)
-                    ciphered_data = cipher.encrypt(data)
-                    # writing
-                    with open(file_name, "rb") as file:
-                        file.write(b"BLO")
-                        file.write(self.marker)
-                        file.write(iv)
-                        file.write(salt)
-                        file.write(key_signature)
-                        file.write(ciphered_data)
+        # checking if file is suitable
+        return_code = self.check_path_validity(path, decrypting=False, type_="BLO")
+        if return_code != 0:
+            return return_code
+        # passing onto cython code
+        BLO_encrypt_file(self.password, path)
+        return 0
 
 
     def BLO_decrypt_file(self, path=str):
@@ -545,61 +405,13 @@ class Ciphers:
             7: File was not encrypted.
             8: File was encrypted using a different alogorithm.
         """
-        # file decryption
-        if os.path.isfile(path) is True:
-            # checking if file is suitable
-            return_code = self.check_path_validity(path, decrypting=True, type_="BLO")
-            if return_code != 0:
-                return return_code
-            # getting needed data
-            with open (path, "rb") as file:
-                file.read(3)
-                file.read(14)
-                iv = file.read(8)
-                salt = file.read(32)
-                file_signature = file.read(32)
-                ciphered_data = file.read()
-                # rebuilding the key and getting its signature
-            key = self.generate_symmetric_key(salt=salt)
-            key_hash = hash.sha256(key); key_signature = key_hash.hexdigest()
-            if key_signature != file_signature:
-                raise BadKeyError("Key provided was different from the one used for encryption.")
-            # setting cipher and decrypting data
-            cipher = Blowfish.new(key, Blowfish.MODE_CFB, iv=iv)
-            # writing
-            original_data = cipher.decrypt(ciphered_data)
-            with open (path, 'wb') as file:
-                file.write(original_data)
-            return 0
-        # directory decryption
-        elif os.path.isdir(path) is True:
-            # looping through files
-            for root, dirs, files in os.walk(path):
-                for file in files:
-                    # checking if file is suitable
-                    file_name = os.path.join(root, file)
-                    return_code = self.check_path_validity(file_name, decrypting=True, type_="BLO")
-                    if return_code != 0:
-                        continue
-                    # getting data
-                    with open (file_name) as file:
-                        file.read(3)
-                        file.read(14)
-                        iv = file.read(8)
-                        salt = file.read(32)
-                        file_signature = file.read(32)
-                        ciphered_data = file.read()
-                    # building key and key signature
-                    key = self.generate_symmetric_key(salt)
-                    key_hash = hash.sha256(key); key_signature = key_hash.hexdigest()
-                    if key_signature != file_signature:
-                        continue
-                    # setting the cipher and decrypting
-                    cipher = Blowfish.new(key, Blowfish.MODE_CFB, iv=iv)
-                    original_data = cipher.decrypt(ciphered_data)
-                    # writing the data
-                    with open (file_name, "wb") as file:
-                        file.write(original_data)
+        # checking if file is suitable
+        return_code = self.check_path_validity(path, decrypting=True, type_="BLO")
+        if return_code != 0:
+            return return_code
+        # passsing onto cython code
+        BLO_decrypt_file(self.password, path)
+        return 0
 
 
     def BLO_encrypt_string(self, string_to_encrypt:bytes, key=None):
