@@ -1,6 +1,6 @@
 from setuptools import setup, find_packages
-
-VERSION = "0.4.0"
+from Cython.Build import cythonize
+VERSION = "0.4.2"
 DESCRIPTION = "A module for encryption and information security operations."
 setup(
     name= "better cryptography",
@@ -12,6 +12,7 @@ setup(
     long_description_content_type="text/markdown",
     packages = find_packages(),
     install_requires = ['pycryptodome', "rsa", "cryptography"],
+    ext_modules=cythonize(["better_cryptography/file_encryption.pyx"]),
     keywords=["python", "encryption", "AES", "information security"],
     classifiers= [
         "Development Status :: 3 - Alpha",
